import spdist
import numpy as np


def main():
    x = np.linspace(0, 10, 10000)
    y = x

    x_ref = x
    y_ref = x + 1

    print(spdist.spdist(x, y, x_ref, y_ref))


if __name__ == "__main__":
    main()



import numpy as np
import matplotlib.pyplot as plt
import spdist

x = np.linspace(0, 10, 100)
y = 2 * x

x_ref = x
y_ref = 2 * x + 1

distance = spdist.spdist(x, y, x_ref, y_ref)

point_x = 1
point_y = 2 * point_x + 1
normal_vector = np.array([2, -1]) / np.linalg.norm([2, -1])
endpoint_x = point_x + normal_vector[0] * distance
endpoint_y = point_y + normal_vector[1] * distance

fig, ax = plt.subplots(1, 1, figsize=(6, 6))
ax.plot(x, y, label="y")
ax.plot(x_ref, y_ref, label="y_ref")
ax.plot([point_x, endpoint_x], [point_y, endpoint_y], label="normal_vector*distance")
ax.text(endpoint_x + 0.1, endpoint_y - 0.1, f"distance = {distance:.2f}")
ax.set_xlim(0, 10)
ax.set_ylim(0, 10)
ax.set_xlabel("x")
ax.set_ylabel("y")
ax.legend()

fig.tight_layout()
fig.savefig("readme_plot.png", dpi=300)



""" Collection of functions to calculate the distance between two curves using spdist metric.

The main fucntions are:
- `spdist`: calculate the distance between two curves using spdist metric.
- `spdist_vector`: calculate the distance between two curves using spdist metric and return a vector of distances.
- `squared_spdist`: calculate the squared distance between two curves using squared spdist metric.
- `squared_spdist_vector`: calculate the squared distance between two curves using squared spdist metric and return a vector of distances.
"""

import numpy as np

def spdist(x: np.ndarray, y: np.ndarray, x_ref: np.ndarray, y_ref: np.ndarray) -> float:
    """Calculate the distance between two curves using spdist metric.

    The distance is calculated by finding the minimum distance between each point in the first curve and the reference curve.
    The distance is only calculated correctly if the `x_ref` is sorted.
    Please refer to [wikipedia](https://en.wikipedia.org/wiki/Distance_from_a_point_to_a_line#Line_defined_by_two_points) for more information of the distance calculation.


    Args:
        x (np.ndarray): array of x coordinates of curve 1
        y (np.ndarray): array of y coordinates of curve 1
        x_ref (np.ndarray): array of x coordinates of reference curve
        y_ref (np.ndarray): array of y coordinates of reference curve

    Returns:
        float: minium distance between two curves using spdist metric.
    """

def spdist_vector(
    x: np.ndarray, y: np.ndarray, x_ref: np.ndarray, y_ref: np.ndarray
) -> np.ndarray:
    """Calculate the distance between two curves using spdist metric and return a vector of distances.
    The distance is calculated by finding the minimum distance between each point in the first curve and the reference curve.
    The distance is only calculated correctly if the `x_ref` is sorted.
    Please refer to [wikipedia](https://en.wikipedia.org/wiki/Distance_from_a_point_to_a_line#Line_defined_by_two_points) for more information of the distance calculation.

    Args:
        x (np.ndarray): array of x coordinates of curve 1
        y (np.ndarray): array of y coordinates of curve 1
        x_ref (np.ndarray): array of x coordinates of reference curve
        y_ref (np.ndarray): array of y coordinates of reference curve

    Returns:
        np.ndarray: vector of distances between two curves using spdist metric.
    """

def squared_spdist(
    x: np.ndarray, y: np.ndarray, x_ref: np.ndarray, y_ref: np.ndarray
) -> float:
    """Calculate the squared distance between two curves using squared spdist metric.
    The distance is calculated by finding the minimum squared distance between each point in the first curve and the reference curve.
    The distance is only calculated correctly if the `x_ref` is sorted.
    Please refer to [wikipedia](https://en.wikipedia.org/wiki/Distance_from_a_point_to_a_line#Line_defined_by_two_points) for more information of the distance calculation. The squared distance is calculated by squaring the distance.

    Args:
        x (np.ndarray): array of x coordinates of curve 1
        y (np.ndarray): array of y coordinates of curve 1
        x_ref (np.ndarray): array of x coordinates of reference curve
        y_ref (np.ndarray): array of y coordinates of reference curve

    Returns:
        float: minium distance between two curves using squared spdist metric.
    """

def squared_spdist_vector(
    x: np.ndarray, y: np.ndarray, x_ref: np.ndarray, y_ref: np.ndarray
) -> np.ndarray:
    """Calculate the squared distance between two curves using squared spdist metric and return a vector of distances.
    The distance is calculated by finding the minimum squared distance between each point in the first curve and the reference curve.
    The distance is only calculated correctly if the `x_ref` is sorted.
    Please refer to [wikipedia](https://en.wikipedia.org/wiki/Distance_from_a_point_to_a_line#Line_defined_by_two_points) for more information of the distance calculation. The squared distance is calculated by squaring the distance.

    Args:
        x (np.ndarray): array of x coordinates of curve 1
        y (np.ndarray): array of y coordinates of curve 1
        x_ref (np.ndarray): array of x coordinates of reference curve
        y_ref (np.ndarray): array of y coordinates of reference curve

    Returns:
        np.ndarray: vector of distances between two curves using squared spdist metric.
    """
